@@ -351,7 +351,7 @@ sigPADT(int src)
 void
 usage(char const *argv0)
 {
-#if 0
+/* #if 0 */
     fprintf(stderr, "Usage: %s [options]\n", argv0);
     fprintf(stderr, "Options:\n");
 #ifdef USE_BPF
@@ -381,7 +381,7 @@ usage(char const *argv0)
     fprintf(stderr, "This is free software, and you are welcome to redistribute it under the terms\n");
     fprintf(stderr, "of the GNU General Public License, version 2 or any later version.\n");
     fprintf(stderr, "http://www.roaringpenguin.com\n");
-#endif
+/* #endif */
     exit(EXIT_SUCCESS);
 }
 
@@ -652,11 +652,11 @@ fatalSys(char const *str)
 void
 sysErr(char const *str)
 {
-#if 0
+/* #if 0 */
     char buf[1024];
     sprintf(buf, "%.256s: %.256s", str, strerror(errno));
     printErr(buf);
-#endif
+/* #endif */
 }
 
 /**********************************************************************
