@@ -203,7 +203,7 @@ removeBytes(PPPoEPacket *packet,
 void
 relay_usage(char const *argv0)
 {
-#if 0
+/* #if 0 */
     fprintf(stderr, "Usage: %s [options]\n", argv0);
     fprintf(stderr, "Options:\n");
     fprintf(stderr, "   -S if_name     -- Specify interface for PPPoE Server\n");
@@ -219,7 +219,7 @@ relay_usage(char const *argv0)
     fprintf(stderr, "This is free software, and you are welcome to redistribute it under the terms\n");
     fprintf(stderr, "of the GNU General Public License, version 2 or any later version.\n");
     fprintf(stderr, "http://www.roaringpenguin.com\n");
-#endif
+/* #endif */
     exit(EXIT_SUCCESS);
 }
 
@@ -933,7 +933,7 @@ relayGotSessionPacket(PPPoEInterface const *iface)
     packet.session = sh->sesNum;
     memcpy(packet.ethHdr.h_source, sh->interface->mac, ETH_ALEN);
     memcpy(packet.ethHdr.h_dest, sh->peerMac, ETH_ALEN);
-#if 0
+/* #if 0 */
     fprintf(stderr, "Relaying %02x:%02x:%02x:%02x:%02x:%02x(%s:%d) to %02x:%02x:%02x:%02x:%02x:%02x(%s:%d)\n",
 	    sh->peer->peerMac[0], sh->peer->peerMac[1], sh->peer->peerMac[2],
 	    sh->peer->peerMac[3], sh->peer->peerMac[4], sh->peer->peerMac[5],
@@ -941,7 +941,7 @@ relayGotSessionPacket(PPPoEInterface const *iface)
 	    sh->peerMac[0], sh->peerMac[1], sh->peerMac[2],
 	    sh->peerMac[3], sh->peerMac[4], sh->peerMac[5],
 	    sh->interface->name, ntohs(sh->sesNum));
-#endif
+/* #endif */
     sendPacket(NULL, sh->interface->sessionSock, &packet, size);
 }
 
